# Generated by roxygen2: do not edit by hand

S3method(format,tx_career)
S3method(format,tx_run)
S3method(print,tx_career)
S3method(print,tx_progress)
S3method(print,tx_run)
S3method(summary,tx_career)
S3method(summary,tx_run)
export(abstract)
export(achievements)
export(career)
export(funding)
export(graphical_abstract)
export(manuscript)
export(presentation)
export(progress)
export(reset_achievements)
export(reset_all)
export(reset_career)
export(reset_wardrobe)
export(reviewer_response)
export(run_log)
export(shoot)
export(validate_messages)
export(vocab_careers)
export(vocab_effects)
export(vocab_mascot_states)
export(vocab_phases)
export(vocab_tags)
export(wardrobe)
importFrom(Rcpp,evalCpp)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,model.frame)
importFrom(stats,na.omit)
importFrom(stats,runif)
importFrom(stats,sd)
useDynLib(texanshootR, .registration = TRUE)
