# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

ols_fit_cpp <- function(X, y) {
    .Call(`_texanshootR_ols_fit_cpp`, X, y)
}

ols_fit_batch_cpp <- function(Xs, ys) {
    .Call(`_texanshootR_ols_fit_batch_cpp`, Xs, ys)
}

pls_gcv_cpp <- function(X, y, S, log_lambdas) {
    .Call(`_texanshootR_pls_gcv_cpp`, X, y, S, log_lambdas)
}

lmm_profile_cpp <- function(X, y, group, n_groups, log_thetas) {
    .Call(`_texanshootR_lmm_profile_cpp`, X, y, group, n_groups, log_thetas)
}

