utils::globalVariables(c(
  ".tx",
  "id",
  "rarity",
  "trigger_phase",
  "career_min",
  "tags",
  "model_family_affinity",
  "mascot_state_affinity",
  "combo_chain",
  "text",
  "weight",
  "weight_recency",
  "weight_combo",
  "weight_final",
  # ggplot2 aesthetic columns referenced inside aes()
  "x",
  "y",
  # Rcpp-generated wrappers (R/RcppExports.R) — referenced from
  # R/families.R via bare names through devtools::load_all().
  "pls_gcv_cpp",
  "lmm_profile_cpp",
  "ols_fit_cpp",
  "ols_fit_batch_cpp"
))
