% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/achievements.R
\name{achievements}
\alias{achievements}
\title{Inspect the achievement registry}
\usage{
achievements()
}
\value{
A data.frame.
}
\description{
Returns a data.frame of all achievements with unlock status. Hidden
achievements appear with \code{name = "???"} and \code{hint = NA} until
unlocked.
}
