% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/run.R
\name{run_log}
\alias{run_log}
\title{Browse persisted run history}
\usage{
run_log(n = 25L)
}
\arguments{
\item{n}{Maximum number of runs to list.}
}
\value{
A data.frame with one row per run.
}
\description{
Returns a data.frame of recent runs with one row per run. The full
run record can be loaded via \code{attr(run_log(), "records")[[i]]}.
}
