% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vocab.R
\docType{data}
\name{vocab}
\alias{vocab}
\alias{vocab_tags}
\alias{vocab_phases}
\alias{vocab_careers}
\alias{vocab_mascot_states}
\alias{vocab_effects}
\alias{career_levels}
\title{Controlled vocabularies for the message and event registries}
\format{
An object of class \code{character} of length 39.

An object of class \code{character} of length 16.

An object of class \code{character} of length 4.

An object of class \code{character} of length 9.

An object of class \code{character} of length 9.
}
\usage{
vocab_tags

vocab_phases

vocab_careers

vocab_mascot_states

vocab_effects

career_levels()
}
\description{
These exported character vectors define the valid values for the
\code{tags}, \code{career_min}, \code{trigger_phase}, \code{mascot_state_affinity}, and
event \code{effects} fields used in \verb{inst/messages/*.yaml} and
\verb{inst/events/*.yaml}. \code{\link[=validate_messages]{validate_messages()}} enforces them.
}
\section{Functions}{
\itemize{
\item \code{vocab_tags}: Valid \code{tags} values. The lower-case fallacy
names from the design contract plus thematic content tags.

\item \code{vocab_phases}: Valid \code{trigger_phase} values.

\item \code{vocab_careers}: Valid \code{career_min} values.

\item \code{vocab_mascot_states}: Valid \code{mascot_state_affinity} values.

\item \code{vocab_effects}: Valid event-effect keys for \verb{inst/events/*.yaml}.

\item \code{career_levels()}: Career level ordering (low to high).

}}
\keyword{datasets}
\keyword{internal}
